==> sphinx-togglebutton_0.3.2.orig.tar.gz: sphinx-togglebutton-0.3.2/CHANGELOG.md <==
# Changelog

## v0.3.2 - 2022-07-15

([full changelog](https://github.com/executablebooks/sphinx-togglebutton/compare/v0.3.1...347b1ad3a093afad0f0d4c0041249f09f39afab2))

### Enhancements made

- Toggle arrow now points to the right, in order to more closely match the styles of other common documentation themes like Quarto and Material for MkDocs [#49](https://github.com/executablebooks/sphinx-togglebutton/pull/49) ([@choldgraf](https://github.com/choldgraf))
- Toggle buttons are now more minimal and take up the full width to be easier to click, style is roughly inspired by JupyterLab [#47](https://github.com/executablebooks/sphinx-togglebutton/pull/47) ([@choldgraf](https://github.com/choldgraf))

### Bugfixes

- Fix insertion of toggle hint into nested spans [#45](https://github.com/executablebooks/sphinx-togglebutton/pull/45) ([@janssenhenning](https://github.com/janssenhenning))

### Contributors to this release

[@Apteryks](https://github.com/search?q=repo%3Aexecutablebooks%2Fsphinx-togglebutton+involves%3AApteryks+updated%3A2022-03-26..2022-07-15&type=Issues) | [@choldgraf](https://github.com/search?q=repo%3Aexecutablebooks%2Fsphinx-togglebutton+involves%3Acholdgraf+updated%3A2022-03-26..2022-07-15&type=Issues) | [@janssenhenning](https://github.com/search?q=repo%3Aexecutablebooks%2Fsphinx-togglebutton+involves%3Ajanssenhenning+updated%3A2022-03-26..2022-07-15&type=Issues) | [@tfiers](https://github.com/search?q=repo%3Aexecutablebooks%2Fsphinx-togglebutton+involves%3Atfiers+updated%3A2022-03-26..2022-07-15&type=Issues) | 

## v0.3.1

This is release updates the behavior of the toggle button arrow for admonitions, to point down/up instead of down/right. See [#38](https://github.com/executablebooks/sphinx-togglebutton/issues/38) for details.

## v0.3.0

([full changelog](https://github.com/executablebooks/sphinx-togglebutton/compare/v0.2.3...9e73e2e1a673d2485dd8c8d56510cdf910531f1a))

### Enhancements made

- ENH: Enhance toggle button design and layout [#32](https://github.com/executablebooks/sphinx-togglebutton/pull/32) ([@choldgraf](https://github.com/choldgraf))
- IMPROVE: Allow clicking on whole admonition title [#29](https://github.com/executablebooks/sphinx-togglebutton/pull/29) ([@rkdarst](https://github.com/rkdarst))
- ENHANCE: Improve hiding behavior for togglebuttons [#33](https://github.com/executablebooks/sphinx-togglebutton/pull/33) ([@choldgraf](https://github.com/choldgraf))

## v0.2.2
([full changelog](https://github.com/executablebooks/sphinx-togglebutton/compare/v0.2.0...v0.2.2))


### Bugs fixed
* 🐛 BUG: fixing toggle button text overlap on narrow screens [#17](https://github.com/executablebooks/sphinx-togglebutton/pull/17) ([@choldgraf](https://github.com/choldgraf))
* 🐛 BUG: Fixing overlapping title on hidden admonitions [#15](https://github.com/executablebooks/sphinx-togglebutton/pull/15) ([@choldgraf](https://github.com/choldgraf))

### Documentation improvements
* 📚 DOC: release docs and removing circle [#16](https://github.com/executablebooks/sphinx-togglebutton/pull/16) ([@choldgraf](https://github.com/choldgraf))

### Contributors to this release
([GitHub contributors page for this release](https://github.com/executablebooks/sphinx-togglebutton/graphs/contributors?from=2020-06-09&to=2020-08-08&type=c))

[@choldgraf](https://github.com/search?q=repo%3Aexecutablebooks%2Fsphinx-togglebutton+involves%3Acholdgraf+updated%3A2020-06-09..2020-08-08&type=Issues)

==> sphinx-togglebutton_0.4.4.orig.tar.gz: sphinx-togglebutton-0.4.4/CHANGELOG.md <==
# Changelog

## 0.4.4 - 2026-01-14

### Fixed

- Upgrade used version in release workflow to the latest available.
- Correct build command in `tests.yml`.

## 0.4.3 - 2026-01-14

### Fixed

- Added missing information in `tests.yml`.

## 0.4.2 - 2026-01-14

### Fixed

- Enhanced `setup.cfg` with complete metadata.
- Simplified `setup.py` to just call `setup()`.

## 0.4.1 - 2026-01-14

### Fixed

- Updated the release workflow to use a recent Python version.

## 0.4.0 - 2026-01-14

### Added

- Support for more languages in toggle button text (see README for full list) [#66](https://github.com/executablebooks/sphinx-togglebutton/pull/66).
- Added new functions (syncToggleHint, syncAllToggleHints) to dynamically update toggle button hints based on the current state  [#66](https://github.com/executablebooks/sphinx-togglebutton/pull/66). This allows developers to change the open or closed state of an element and have the button hint text update accordingly automatically.

### Fixed

- Update togglebutton.js to use an admonition's existing ID if present, instead of always generating a new one [#66](https://github.com/executablebooks/sphinx-togglebutton/pull/66).

## v0.3.2 - 2022-07-15

([full changelog](https://github.com/executablebooks/sphinx-togglebutton/compare/v0.3.1...347b1ad3a093afad0f0d4c0041249f09f39afab2))

### Enhancements made

- Toggle arrow now points to the right, in order to more closely match the styles of other common documentation themes like Quarto and Material for MkDocs [#49](https://github.com/executablebooks/sphinx-togglebutton/pull/49) ([@choldgraf](https://github.com/choldgraf))
- Toggle buttons are now more minimal and take up the full width to be easier to click, style is roughly inspired by JupyterLab [#47](https://github.com/executablebooks/sphinx-togglebutton/pull/47) ([@choldgraf](https://github.com/choldgraf))

### Bugfixes

- Fix insertion of toggle hint into nested spans [#45](https://github.com/executablebooks/sphinx-togglebutton/pull/45) ([@janssenhenning](https://github.com/janssenhenning))

### Contributors to this release

[@Apteryks](https://github.com/search?q=repo%3Aexecutablebooks%2Fsphinx-togglebutton+involves%3AApteryks+updated%3A2022-03-26..2022-07-15&type=Issues) | [@choldgraf](https://github.com/search?q=repo%3Aexecutablebooks%2Fsphinx-togglebutton+involves%3Acholdgraf+updated%3A2022-03-26..2022-07-15&type=Issues) | [@janssenhenning](https://github.com/search?q=repo%3Aexecutablebooks%2Fsphinx-togglebutton+involves%3Ajanssenhenning+updated%3A2022-03-26..2022-07-15&type=Issues) | [@tfiers](https://github.com/search?q=repo%3Aexecutablebooks%2Fsphinx-togglebutton+involves%3Atfiers+updated%3A2022-03-26..2022-07-15&type=Issues) | 

## v0.3.1

This is release updates the behavior of the toggle button arrow for admonitions, to point down/up instead of down/right. See [#38](https://github.com/executablebooks/sphinx-togglebutton/issues/38) for details.

## v0.3.0

([full changelog](https://github.com/executablebooks/sphinx-togglebutton/compare/v0.2.3...9e73e2e1a673d2485dd8c8d56510cdf910531f1a))

### Enhancements made

- ENH: Enhance toggle button design and layout [#32](https://github.com/executablebooks/sphinx-togglebutton/pull/32) ([@choldgraf](https://github.com/choldgraf))
- IMPROVE: Allow clicking on whole admonition title [#29](https://github.com/executablebooks/sphinx-togglebutton/pull/29) ([@rkdarst](https://github.com/rkdarst))
- ENHANCE: Improve hiding behavior for togglebuttons [#33](https://github.com/executablebooks/sphinx-togglebutton/pull/33) ([@choldgraf](https://github.com/choldgraf))

## v0.2.2
([full changelog](https://github.com/executablebooks/sphinx-togglebutton/compare/v0.2.0...v0.2.2))


### Bugs fixed
* 🐛 BUG: fixing toggle button text overlap on narrow screens [#17](https://github.com/executablebooks/sphinx-togglebutton/pull/17) ([@choldgraf](https://github.com/choldgraf))
* 🐛 BUG: Fixing overlapping title on hidden admonitions [#15](https://github.com/executablebooks/sphinx-togglebutton/pull/15) ([@choldgraf](https://github.com/choldgraf))

### Documentation improvements
* 📚 DOC: release docs and removing circle [#16](https://github.com/executablebooks/sphinx-togglebutton/pull/16) ([@choldgraf](https://github.com/choldgraf))

### Contributors to this release
([GitHub contributors page for this release](https://github.com/executablebooks/sphinx-togglebutton/graphs/contributors?from=2020-06-09&to=2020-08-08&type=c))

[@choldgraf](https://github.com/search?q=repo%3Aexecutablebooks%2Fsphinx-togglebutton+involves%3Acholdgraf+updated%3A2020-06-09..2020-08-08&type=Issues)
